API docs for “spamfighter.txjsonrpc.web.jsonrpc.JSONRPC”

# Class s.t.w.j.JSONRPC(resource.Resource):

Part of spamfighter.txjsonrpc.web.jsonrpc View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.apiglue.JSONRPC_API_Glue, spamfighter.txjsonrpc.web.jsonrpc.JSONRPCIntrospection, spamfighter.txjsonrpc.web.test.test_jsonrpc.Test

A resource that implements JSON-RPC.

Methods published can return JSON-RPC serializable results, Faults, Binary, Boolean, DateTime, Deferreds, or Handler instances.

By default methods beginning with 'jsonrpc_' are published.

Sub-handlers for prefixed methods (e.g., system.listMethods) can be added with putSubHandler. By default, prefixes are separated with a '.'. Override self.separator to change this.

Method | __init__ | Undocumented
Method | putSubHandler | Undocumented
Method | getSubHandler | Undocumented
Method | getSubHandlerPrefixes | Undocumented
Method | render | Undocumented
Method | _cbRender | Undocumented
Method | _ebRender | Undocumented
Method | _getFunction | Given a string, return a function, or raise jsonrpclib.NoSuchFunction.
Method | _listFunctions | Return a list of the names of all jsonrpc methods.

def __init__(self): (source)
overridden in spamfighter.txjsonrpc.web.jsonrpc.JSONRPCIntrospection, spamfighter.txjsonrpc.web.test.test_jsonrpc.TestAuthHeader
Undocumented
def putSubHandler(self, prefix, handler): (source)
Undocumented
def getSubHandler(self, prefix): (source)
Undocumented
def getSubHandlerPrefixes(self): (source)
Undocumented
def render(self, request): (source)
overridden in spamfighter.txjsonrpc.web.test.test_jsonrpc.TestAuthHeader
Undocumented
def _cbRender(self, result, request, requestId): (source)
Undocumented
def _ebRender(self, failure, requestId): (source)
Undocumented
def _getFunction(self, functionPath): (source)
overridden in spamfighter.core.commands.apiglue.JSONRPC_API_Glue, spamfighter.txjsonrpc.web.test.test_jsonrpc.Test
Given a string, return a function, or raise jsonrpclib.NoSuchFunction.

This returned function will be called, and should return the result of the call, a Deferred, or a Fault instance.

Override in subclasses if you want your own policy. The default policy is that given functionPath 'foo', return the method at self.jsonrpc_foo, i.e. getattr(self, "jsonrpc_" + functionPath). If functionPath contains self.separator, the sub-handler for the initial prefix is used to search for the remaining path.

def _listFunctions(self): (source)
Return a list of the names of all jsonrpc methods.